from typing import Literal

Overflow = Literal[
    'auto',
    'hidden',
    'clip',
    'visible',
    'scroll',
    'x-auto',
    'y-auto',
    'x-hidden',
    'y-hidden',
    'x-clip',
    'y-clip',
    'x-visible',
    'y-visible',
    'x-scroll',
    'y-scroll',
]
